#define _CRT_SECURE_NO_WARNINGS

#include <iostream>
#include <cstdio>
#include <algorithm>
#include <vector>
#include <string>
#include <cstring>
#include <map>
#include <set>
#include <cmath>

using namespace std;

typedef long long LL;
typedef long double dbl;

const int MAXN = 150001;
const dbl EPS = 1e-9;

struct Buyer {
  int a, b;
  
  bool operator<(const Buyer &o) const {
    return b != o.b ? b < o.b : a < o.a;
  }
};

int n;
Buyer b[MAXN];

struct Point {
  dbl x, y;
  bool operator<(const Point &p) const {
    return abs(x - p.x) > EPS ? x < p.x : y < p.y;
  }
};

struct Line {
  LL k, b;

  bool isUpper(const Point &p) const {
    return k * p.x + b - p.y > EPS;
  }

  Point intersect(const Line &l) const {
    dbl x = (l.b - b) / (k - l.k);
    return Point{ x, k * x + b };
  }
};

struct CHT {
  vector<Line> lines;
  vector<Point> points;

  CHT() {
    lines.push_back(Line{ (LL)-1e9, (LL)-1e18 });
  }

  void add(Line l) {
    while (points.size() && ((l.k == lines.back().k && l.b >= lines.back().b) || l.isUpper(points.back()))) {
      points.pop_back();
      lines.pop_back();
    }
    if (l.k <= lines.back().k && l.b <= lines.back().b) return;
    points.push_back(l.intersect(lines.back()));
    lines.push_back(l);
  }

  Line get(LL x) {
    int it = lower_bound(points.begin(), points.end(), Point{ x - EPS, (LL)-1e18 }) - points.begin();
    return lines[it];
  }
};

int main() {
#ifdef _DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#endif
  cin.tie(0);
  ios::sync_with_stdio(0);

  cin >> n;

  for (int i = 0; i < n; ++i)
    cin >> b[i].a >> b[i].b;

  sort(b, b + n);

  vector<pair<int, int>> ordera(n);
  for (int i = 0; i < n; ++i) {
    ordera[i] = { b[i].a, i };
  }
  sort(ordera.begin(), ordera.end());

  LL ans = 0;
  int left = n;
  
  int BSIZE = ceil(sqrt(n));
  int rebuildt = 0;
  LL bmax = 0;

  CHT bs;
  vector<int> pmax;
  vector<int> bbs;
  
  for (pair<int, int> a : ordera) {
    int sz = n - left;
    Line l = bs.get(sz);
    LL bmax = max<LL>(0, l.k * sz + l.b);
    ans = max(ans, left * 1ll * a.first + bmax);
    left--;
    bs.add(Line{ b[a.second].b, -sz * 1ll * b[a.second].b });
  }

  cout << ans << '\n';
 
  return 0;
}
/*bmax = 0;

int sz = n - left;
Line l = bs.get(sz + pmax.size());

bmax = max<LL>(0, l.k * sz + l.b);
for (int i = 0; i < pmax.size(); ++i) {
}

ans = max(ans, left * 1ll * a.first + bmax);
left--;

pmax.push_back(b[a.second].b);

if (++rebuildt >= BSIZE) {
rebuildt = 0;

bs = CHT();

for (auto t : pmax)
bbs.push_back(t);

sort(bbs.begin(), bbs.end());
pmax.clear();

for (int i = 0; i < bbs.size(); ++i) {
bs.add(Line{ bbs[i], -i * 1ll * bbs[i] });
}
}
*/