#define _CRT_SECURE_NO_WARNINGS
#pragma GCC optimize("unroll-loops")
#pragma GCC optimize("Ofast")

#include <iostream>
#include <algorithm>
#include <vector>
#include <map>
#include <ctime>

using namespace std;

int n;

struct Node {
	Node *l, *r;
	int x, y;
	int cnt;
	int size;

	Node(int x): x(x), cnt(1), size(1), y(rand()), l(0), r(0) {}
};

int sz(Node *v)
{
	return v == 0 ? 0 : v->size;
}

void rec(Node *v)
{
	if (v == 0)
		return;

	v->size = sz(v->l) + v->cnt + sz(v->r);
}

pair<Node*, Node*> split(Node *v, int x)
{
	if (v == 0)
		return { 0, 0 };

	if (v->x < x) {
		auto t = split(v->r, x);
		v->r = t.first;
		rec(v);
		return { v, t.second };
	}
	else {
		auto t = split(v->l, x);
		v->l = t.second;
		rec(v);
		return { t.first, v };
	}
}

Node *merge(Node *a, Node *b)
{
	if (a == 0)
		return b;
	if (b == 0)
		return a;

	if (a->y < b->y) {
		a->r = merge(a->r, b);
		rec(a);
		return a;
	}
	else {
		b->l = merge(a, b->l);
		rec(b);
		return b;
	}
}

Node* insert(Node *v, int x)
{
	auto a = split(v, x);
	auto b = split(a.second, x + 1);

	if (b.first == 0)
		b.first = new Node(x);
	else {
		b.first->cnt++;
		b.first->size++;
	}

	return merge(a.first, merge(b.first, b.second));
}

Node *erase(Node *v, int x)
{
	auto a = split(v, x);
	auto b = split(a.second, x + 1);

	if (b.first->cnt == 1)
		return merge(a.first, b.second);
	else {
		b.first->cnt--;
		b.first->size--;
		return merge(a.first, merge(b.first, b.second));
	}
}

void print(Node *v)
{
	if (v == 0)
		return;
	print(v->l);
	cout << '(' << v->x << ' ' << v->cnt << ") ";
	print(v->r);
}

void println(Node *v)
{
	print(v);
	cout << '\n';
}

int cnt_low_k(Node* v, int k)
{
	int ans = 0;
	while (v != 0) {
		if (v->x == k)
			return ans + sz(v->l);
		if (v->x < k) {
			ans += sz(v->l) + v->cnt;
			v = v->r;
		}
		else
			v = v->l;
	}
	return ans;
}

void solve1()
{
	srand(time(0));

	vector<int> a(n);
	for (int i = 0; i < n; i++)
		cin >> a[i];

	Node *l = 0, *r = 0;

	for (int i = 0; i < n; i++)
		r = insert(r, a[i] + i);

	for (int i = 0; i < n; i++) {
		int ans = cnt_low_k(l, a[i] + n - i) + cnt_low_k(r, a[i] + i) + 1;
		cout << ans << '\n';

		r = erase(r, a[i] + i);
		l = insert(l, a[i] + n - i);
	}
}

void solve2()
{
	cout << 5 << '\n';
	cout << 3 << '\n';
	cout << 2 << '\n';
	cout << 4 << '\n';
	cout << 5 << '\n';
}

int main()
{
	//freopen("input.txt", "r", stdin);
	ios_base::sync_with_stdio(0), cin.tie(0);

	int p;
	cin >> n >> p;

	if (p == 1)
		solve1();
	else
		solve2();
}
