#include <iostream>
#include <cmath>
#include <vector>
#include <algorithm>
#include <map>

using namespace std;

const long long inf = 1e15;




struct node {
	long long l, r;
	node * cl;
	node * cr;
	long long max;
	long long pos;

	node() {
		l = r = max = 0;
		cl = cr = nullptr;
	}
};

node * build(long long l, long long r, vector < long long > &a) {
	if (l > r) return nullptr;
	node * root = new node();
	root->l = l;
	root->r = r;

	if (l == r) {
		root->max = a[l];
		root->pos = l;
		return root;
	}

	long long mid = (l + r) / 2;

	root->cl = build(l, mid, a);
	root->cr = build(mid + 1, r, a);

	if (root->cl->max > root->cr->max) {
		root->max = root->cl->max;
		root->pos = root->cl->pos;
	}
	else {
		root->max = root->cr->max;
		root->pos = root->cr->pos;
	}
	return root;
}

void update(node * root, long long id, long long val) {
	if (root->l > id || root->r < id) {
		return;
	}

	if (root->l == root->r) {
		root->max = val;
		return;
	}

	update(root->cl, id, val);
	update(root->cr, id, val);

	if (root->cl->max > root->cr->max) {
		root->max = root->cl->max;
		root->pos = root->cl->pos;
	}
	else {
		root->max = root->cr->max;
		root->pos = root->cr->pos;
	}
	return;
}

pair < long long, long long > query(node * root, long long l, long long r) {
	if (root->l > r || root->r < l) {
		return { -inf, -1 };
	}

	if (root->l >= l && root->r <= r) {
		return { root->max, root->pos };
	}

	auto ans1 = query(root->cl, l, r);
	auto ans2 = query(root->cr, l, r);

	if (ans1.first > ans2.first) {
		return ans1;
	}
	return ans2;
}

int main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);
	long long n;
	cin >> n;

	vector < long long > a(n);

	vector < int > pos(n, n); // pos[i] -     i
	vector < pair < int, int > > temp;

	for (long long i = 0; i < n; i++) {
		cin >> a[i];

		while (true) {
			if (temp.size() == 0) break;
			auto val = temp.back();
			if (a[i] < val.first) {
				temp.pop_back();
				pos[val.second] = i;
			}
			else {
				break;
			}
		}

		temp.push_back({ a[i], i });

	}

	node * root = build(0, n - 1, a);

	long long ans = 0;
	long long l = 0;

	while (l < n) {
		ans++;
		long long r = pos[l];
		r--;
		auto q = query(root, l, r);
		long long border = q.second;
		l = border + 1;
	}

	cout << ans;

	system("pause");
	return 0;
}