#include <iostream>
#include <vector>
#include <algorithm>
#include <map>
#include <cassert>
#include <stack>

using namespace std;

typedef long long ll;

const int N = 1e3;

vector <int> t[4 * N];
int mod[4 * N];

void update(int v, int delta = 1) {
	for (auto &c : t[v]) {
		c += delta;
	}
	mod[v] += delta;
}

void push(int v) {
	if (mod[v]) {
		update(2 * v + 1, mod[v]);
		update(2 * v + 2, mod[v]);
		mod[v] = 0;
	}
}

void my_merge(vector <int> &a, vector <int> &b, vector <int> &c) {
	int l = 0, r = 0;
	a.clear();
	while (l < b.size() || r < c.size()) {
		if (l == b.size() || b[l] <= c[r]) {
			a.push_back(b[l]);
			++l;
		}
		else {
			a.push_back(c[r]);
			++r;
		}
	}
}

void build(int l, int r, int v, vector <int> &a) {
	if (l == r) {
		t[v].clear();
		t[v].push_back(a[l]);
	}
	else {
		int m = (l + r) >> 1;
		build(l, m, 2 * v + 1, a);
		build(m + 1, r, 2 * v + 2, a);
		my_merge(t[v], t[2 * v + 1], t[2 * v + 2]);
	}
}

void modify(int ql, int qr, int l, int r, int v) {
	if (qr < l || r < ql) return;
	if (ql <= l && r <= qr) {
		update(v);
	}
	else {
		push(v);
		int m = (l + r) >> 1;
		modify(ql, qr, l, m, 2 * v + 1);
		modify(ql, qr, m + 1, r, 2 * v + 2);
		my_merge(t[v], t[2 * v + 1], t[2 * v + 2]);
	}
}

int get(int ql, int qr, int val, int l, int r, int v) {
	push(v);
	if (qr < l || r < ql) return 0;
	if (ql <= l && r <= qr) {
		return lower_bound(t[v].begin(), t[v].end(), val - mod[v]) - t[v].begin();
	}
	int m = (l + r) >> 1;
	return get(ql, qr, val, l, m, 2 * v + 1) + get(ql, qr, val, m + 1, r, 2 * v + 2);
}

int ans[N];

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	//freopen("input.txt", "r", stdin);
	//freopen("output.txt", "w", stdout);
	int n, p;
	cin >> n >> p;
	vector <int> a(n);
	for (int i = 0; i < n; ++i) {
		cin >> a[i];
	}
	if (p == 1) {
		build(0, n - 1, 0, a);
		for (int i = 0; i < n; ++i) {
			if (i) {
				modify(0, i - 1, 0, n - 1, 0);
				ans[i] += get(0, i - 1, a[i], 0, n - 1, 0);
			}
		}
		for (int i = 0; i < 4 * n; ++i) {
			mod[i] = 0;
		}
		build(0, n - 1, 0, a);
		for (int i = n - 1; i >= 0; --i) {
			if (i != n - 1) {
				modify(i + 1, n - 1, 0, n - 1, 0);
				ans[i] += get(i + 1, n - 1, a[i], 0, n - 1, 0);
			}
		}
		for (int i = 0; i < n; ++i) {
			cout << ans[i] + 1 << "\n";
		}
	}
}