#include <iostream>
#include <fstream>
#include <vector>
#include <set>
#include <map>
#include <bitset>
#include <algorithm>
#include <iomanip>
#define ll long long
#define null NULL
#pragma GCC optimize("Ofast")

using namespace std;

struct solver {

	struct node {
		int sum;
		node *l, *r;
		node(int _sum, node *_l, node *_r): sum(_sum), l(_l), r(_r) {}
		node(int _sum): sum(_sum), l(null), r(null) {}
		node(): sum(0), l(null), r(null) {}
	};

	node* build_empty(int tl, int tr) {
		if (tl == tr)
			return new node();
		int tm = (tl + tr) >> 1;
		node *l = build_empty(tl, tm);
		node *r = build_empty(tm + 1, tr);
		return new node(0, l, r);
	}

	node* update(node *t, int pos, int val, int tl, int tr) {
		if (tl == tr) {
			return new node(t->sum + val);
		}
		int tm = (tl + tr) >> 1;
		if (pos <= tm) {
			node *new_l = update(t->l, pos, val, tl, tm);
			return new node(t->sum + val, new_l, t->r);
		}
		else {
			node *new_r = update(t->r, pos, val, tm + 1, tr);
			return new node(t->sum + val, t->l, new_r);
		}
	}

	int get_prefix(node *t0, node *t1, int r, int tl, int tr) {
		//cout << "getting prefix " << r << " " << tl << " " << tr << endl;
		//if (!t0 || !t1)
		//	cout << "kek" << endl;
		if (r < tl)
			return 0;
		if (tl == tr) {
			return (t1->sum - t0->sum);
		}
		int tm = (tl + tr) >> 1;
		if (r >= tm)
			return (t1->l->sum - t0->l->sum + get_prefix(t0->r, t1->r, r, tm + 1, tr));
		else
			return get_prefix(t0->l, t1->l, r, tl, tm);
	}

	int get(node *t, int l, int r, int tl, int tr) {
		if (l > r)
			return 0;
		if (l == tl && r == tr)
			return t->sum;
		int tm = (tl + tr) / 2;
		int res_l = get(t->l, l, min(r, tm), tl, tm);
		int res_r = get(t->r, max(l, tm + 1), r, tm + 1, tr);
		return res_l + res_r;
	}

	vector<node*> t;
	vector<int> a, b, val;
	int n, sz;

	void build() {
		t.push_back(build_empty(0, sz - 1));
		for (int i = 0; i < n; ++i) {
			t.push_back(update(t.back(), a[i], 1, 0, sz - 1));
		}
	}

	void init(vector<int> _a) {
		a = _a;
		b = a;
		val = a;
		sort(val.begin(), val.end());
		val.erase(unique(val.begin(), val.end()), val.end());
		n = a.size();
		sz = val.size();
		for (int i = 0; i < n; ++i) {
			a[i] = lower_bound(val.begin(), val.end(), a[i]) - val.begin();
		}
		build();
	}

	void print() {
		cout << "print" << endl;
		for (int i = 0; i < n; ++i) {
			cout << b[i] << " ";
		}
		cout << endl;
	}

	int get_smaller(int l, int r, int x) {
		int pos = lower_bound(val.begin(), val.end(), x) - val.begin();
		int res = get_prefix(t[l], t[r + 1], pos - 1, 0, sz - 1);
		//print();
		//cout << "get_smaller " << l << " " << r << " " << x << endl;
		//cout << "res = " << res << endl;
		return res;
	}

	int get_bigger(int l, int r, int x) {
		int pos = upper_bound(val.begin(), val.end(), x) - val.begin();
		int res = get(t[r + 1], pos, sz - 1, 0, sz - 1) - get(t[l], pos, sz - 1, 0, sz - 1);
		//print();
		//cout << "get_bigger " << l << " " << r << " " << x << endl;
		//cout << "res = " << res << endl;
		return res;
	}

	solver() {}

};

void try_solver() {
	solver T;
	vector<int> a = {1, 2, 3};
	T.init(a);
	cout << T.get_bigger(1, 2, 2) << endl;
}

const int mx = 1e5;
int n, p;
vector<int> a, b, c;
solver t1, t2, t3;

int main() {
	ios_base::sync_with_stdio(false);
	//try_solver();
	cin >> n >> p;
	a.resize(n);
	b.resize(n);
	c.resize(n);
	for (int i = 0; i < n; ++i) {
		cin >> a[i];
		b[i] = a[i] - i;
		c[i] = a[i] + i;
	}
	t1.init(b);
	t2.init(c);
	t3.init(a);
	for (int i = 0; i < n; ++i) {
		int dl = i;
		int dr = n - 1 - i;
		int res = 0;
		int dist = min(dl, dr);
		if (dl <= dr) {
			int cur = 0;
			cur += t2.get_smaller(0, i - 1, a[i] + i);
			cur += t1.get_smaller(i + 1, i + dist, a[i] - i);
			cur += t3.get_smaller(i + dist + 1, n - 1, a[i] + dist);
			res = max(res, cur);
			cur = 0;
			cur += t1.get_smaller(0, n - 1, a[i] - i);
			res = max(res, cur);
		}
		else {
			int cur = 0;
			cur += t3.get_smaller(0, i - dist - 1, a[i] + dist);
			cur += t2.get_smaller(i - dist, i - 1, a[i] + i);
			cur += t1.get_smaller(i + 1, n - 1, a[i] - i);
			res = max(res, cur);
			cur = 0;
			cur += t2.get_smaller(0, n - 1, a[i] + i);
			res = max(res, cur);
		}
		cout << res + 1 << '\n';
	}
}