#define _CRT_SECURE_NO_WARNINGS

#include <iostream>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <cstdio>
#include <algorithm>

using namespace std;

const int INF = 1e9 + 5;

struct node {
	node* l;
	node* r;
	int key, prior, count;
	int sum;

	node() {
		count = 1;
		sum = 1;
		l = r = nullptr;
		prior = rand();
	}

	node(int key_) {
		count = 1;
		sum = 1;
		l = r = nullptr;
		key = key_;
		prior = rand();
	}
};

int get_cnt(node* v) {
	if (v == nullptr)
		return 0;
	return v->sum;
}

int g(node* v) {
	if (v == nullptr)
		return 0;
	return v->count;
}

void update(node* v) {
	if (v == nullptr)
		return;
	v->sum = get_cnt(v->l) + get_cnt(v->r) + v->count;
}

pair<node*, node*> split(node* v, int key) {
	if (v == nullptr)
		return {nullptr, nullptr};

	if (v->key >= key) {
		auto tmp = split(v->l, key);
		v->l = tmp.second;
		update(v);
		return {tmp.first, v};
	}
	
	auto tmp = split(v->r, key);
	v->r = tmp.first;
	update(v);
	return {v, tmp.second};
}

node* merge(node* l, node* r) {
	if (l == nullptr)
		return r;
	if (r == nullptr)
		return l;

	if (r->prior > l->prior) {
		r->l = merge(l, r->l);
		update(r);
		return r;
	}
	
	l->r = merge(l->r, r);
	update(l);
	return l;
}

bool exists(node* v, int key) {
	if (v == nullptr)
		return false;

	if (key == v->key)
		return true;
	if (key < v->key)
		return exists(v->l, key);
	return exists(v->r, key);
}

void insert(node* &root, int key) {
	auto tmp = split(root, key);
	auto tmp1 = split(tmp.second, key + 1);
	int c = g(tmp1.first);
	tmp1.first = new node(key);
	tmp1.first->count += c;
	update(tmp1.first);

	root = merge(tmp.first, merge(tmp1.first, tmp1.second));
}

void erase(node* &root, int key) {
	if (!exists(root, key))
		return;
	auto tmp = split(root, key);
	auto tmp1 = split(tmp.second, key + 1);
	if (tmp1.first->count > 1) {
		tmp1.first->count--;
		tmp1.first->sum--;
	}
	else
		tmp1.first = nullptr;

	root = merge(tmp.first, merge(tmp1.first, tmp1.second));
}

void ins(int x, vector<int> &v) {
	vector<int> ans;
	for (int i = 0; i < v.size(); i++) {
		if (v[i] <= x)
			ans.push_back(v[i]);
		else
			break;
	}
	ans.push_back(x);
	for (int i = 0; i < v.size(); i++) {
		if (v[i] > x)
			ans.push_back(v[i]);
	}
	v = ans;
}

void er(int x, vector<int> &v) {
	vector<int> ans;
	bool b = 0;
	for (int i = 0; i < v.size(); i++) {
		if (b || (v[i] != x))
			ans.push_back(v[i]);
		else
			b = true;
	}
	v = ans;
}

int count(int x, vector<int> &v) {
	int ans = 0;
	for (int i : v) {
		if (i < x)
			ans++;
	}
	return ans;
}

int main() {
	//freopen("input.txt", "r", stdin);
	//freopen("output.txt", "w", stdout);

	ios::sync_with_stdio(false);

	int n, t;
	cin >> n >> t;

	vector<int> a(n);

	for (int i = 0; i < n; i++)
		cin >> a[i];

	node* left = nullptr;
	node* right = nullptr;
	//vector<int> left, right;

	int l_add = 0, r_add = 0;

	vector<int> key(n);

	for (int i = 0; i < n; i++) {
		//right.push_back(a[i] + i);
		insert(right, a[i] + i);
		key[i] = a[i] + i;
	}

	for (int i = 0; i < n; i++) {
		int ans = 0;
		auto tmp = split(left, a[i] - l_add);
		ans += get_cnt(tmp.first);
		left = merge(tmp.first, tmp.second);

		tmp = split(right, a[i] - r_add);
		ans += get_cnt(tmp.first);
		right = merge(tmp.first, tmp.second);

		cout << ans + 1 << endl;

		erase(right, key[i]);
		insert(left, a[i] - l_add);

		l_add++;
		r_add--;
	}

	return 0;
}