#include <iostream>
#include <cstdlib>
#include <cstdio>
#include <cassert>
#include <climits>
#include <algorithm>
#include <set>
#include <vector>
#pragma GCC optimize("O3")

using namespace std;
typedef unsigned int index;

inline void build(index v, index tl, size_t tr, vector<size_t> &t)/*{{{*/
{
	if (tr - tl == 1)
	{
		t[v] = 0;
		return;
	}
	size_t tm = (tl + tr) / 2;
	build(2 * v + 1, tl, tm, t);
	build(2 * v + 2, (index)tm, tr, t);
	t[v] = 0;
}/*}}}*/

inline void upd(index v, index tl, size_t tr, index pos, vector<size_t> &t)/*{{{*/
{
	if (pos < tl or pos >= tr)
		return;
	if (tr - tl == 1)
	{
		++t[v];
		return;
	}
	size_t tm = (tl + tr) / 2;
	upd(2 * v + 1, tl, tm, pos, t);
	upd(2 * v + 2, (index)tm, tr, pos, t);
	++t[v];
}/*}}}*/

inline size_t get(index v, index tl, size_t tr, index l, size_t r, vector<size_t> &t)/*{{{*/
{
	if (tl >= r or tr <= l)
		return 0;
	if (l <= tl and tr <= r)
		return t[v];
	size_t tm = (tl + tr) / 2;
	return get(2 * v + 1, tl, tm, l, r, t) + get(2 * v + 2, (index)tm, tr, l, r, t);
}/*}}}*/

vector<size_t> ans(const vector<int> &a, vector<size_t> &t)/*{{{*/
{
	vector<pair<int, index>> b(a.size());
	for (index i = 0; i < a.size(); i++)
	{
		b[i] = {a[i] - (int)i, i};
	}
	sort(b.begin(), b.end(), [](const pair<int, index> &x, const pair<int, index> &y)
			{
				return x.first < y.first or (x.first == y.first and x.second > y.second);
			});
	vector<size_t> ans(a.size());
	build(0, 0, a.size(), t);
	for (index i = 0; i < a.size(); i++)
	{
		ans[b[i].second] = get(0, 0, a.size(), 0, b[i].second, t);
		upd(0, 0, a.size(), b[i].second, t);
	}
	return ans;
}/*}}}*/

vector<size_t> ans2(const vector<int> &a, vector<size_t> &t)/*{{{*/

{
	vector<pair<int, index>> b(a.size());
	for (index i = 0; i < a.size(); i++)
	{
		b[i] = {a[i] + (int)i, i};
	}
	sort(b.begin(), b.end(), [](const pair<int, index> &x, const pair<int, index> &y)
			{
				return x.first < y.first or (x.first == y.first and x.second > y.second);

			});
	vector<size_t> ans(a.size());
	build(0, 0, a.size(), t);
	size_t n = a.size();
	for (index i = 0; i < a.size(); i++)
	{
		ans[b[i].second] = get(0, 0, a.size(), (index)(2 * b[i].second + 1 > n ? 2 * b[i].second - n + 1 : 0), b[i].second, t);
		upd(0, 0, a.size(), b[i].second, t);
	}
	return ans;
}/*}}}*/

vector<size_t> ans3(const vector<int> &a, vector<size_t> &t)/*{{{*/
{
	vector<pair<int, int>> b;
	size_t n = a.size();
	for (index i = 0; i < a.size(); i++)
	{
		b.push_back({a[i], (int)i + 1});
		if (2 * i >= n)
		{
			b.push_back({a[i] + n - i - 1, -(int)i - 1});
		}
	}
	sort(b.begin(), b.end());
	vector<size_t> ans(a.size());
	build(0, 0, a.size(), t);
	for (index i = 0; i < b.size(); i++)
	{
		if (b[i].second > 0)
		{
			upd(0, 0, a.size(), b[i].second - 1, t);
		}
		else
		{
			ans[-b[i].second - 1] = get(0, 0, a.size(), 0, 2 * (-b[i].second - 1) - n + 1, t);
		}
	}
	return ans;
}/*}}}*/

vector<size_t> ans4(const vector<int> &a, vector<size_t> &t)/*{{{*/
{
	vector<pair<int, index>> b(a.size());
	for (index i = 0; i < a.size(); i++)
	{
		b[i] = {a[i] + (int)i, i};
	}
	sort(b.begin(), b.end(), [](const pair<int, index> &x, const pair<int, index> &y)
			{
				return x.first < y.first or (x.first == y.first and x.second > y.second);
			});
	vector<size_t> ans(a.size());
	build(0, 0, a.size(), t);
	for (index i = 0; i < a.size(); i++)
	{
		ans[b[i].second] = get(0, 0, a.size(), 0, b[i].second, t);
		upd(0, 0, a.size(), b[i].second, t);
	}
	return ans;
}/*}}}*/

int main()
{
#ifdef ONPC
	assert(freopen("a.in", "r", stdin));
	assert(freopen("a.out", "w", stdout));
#else
#endif
	ios::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);
	size_t n, p;
	cin >> n >> p;
	vector<int> a(n);
	for (auto &i: a)
		cin >> i;
	vector<size_t> t(4 * n);
	auto x = ans(a, t);
	auto x1 = ans2(a, t);
	auto x2 = ans3(a, t);
	auto x3 = ans4(a, t);
	reverse(a.begin(), a.end());
	auto y = ans(a, t);
	auto y1 = ans2(a, t);
	auto y2 = ans3(a, t);
	auto y3 = ans4(a, t);
	reverse(y.begin(), y.end());
	reverse(y1.begin(), y1.end());
	reverse(y2.begin(), y2.end());
	reverse(y3.begin(), y3.end());
	for (index i = 0; i < n; i++)
	{
		if (i < n / 2)
		{
			cout << max(x[i] + y3[i], x1[i] + y1[i] + y2[i]) + 1 << "\n";
		}
		else
		{
			cout << max(x3[i] + y[i], x1[i] + y1[i] + x2[i]) + 1 << "\n";
		}
	}
}
